==> okta-sdk-api-19.0.1-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/LinksEnroll.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.LinksEnrollEnroll;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * LinksEnroll
 */
@JsonPropertyOrder({ LinksEnroll.JSON_PROPERTY_ENROLL })
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class LinksEnroll implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_ENROLL = "enroll";
    private LinksEnrollEnroll enroll;

    public LinksEnroll() {
    }

    public LinksEnroll enroll(LinksEnrollEnroll enroll) {

        this.enroll = enroll;
        return this;
    }

    /**
     * Get enroll
     *
     * @return enroll
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_ENROLL)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public LinksEnrollEnroll getEnroll() {
        return enroll;
    }

    @JsonProperty(JSON_PROPERTY_ENROLL)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setEnroll(LinksEnrollEnroll enroll) {
        this.enroll = enroll;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        LinksEnroll linksEnroll = (LinksEnroll) o;
        return Objects.equals(this.enroll, linksEnroll.enroll);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(enroll);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class LinksEnroll {\n");
        sb.append("    enroll: ").append(toIndentedString(enroll)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-24.0.0-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/LinksEnroll.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.LinksEnrollEnroll;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * LinksEnroll
 */
@JsonPropertyOrder({ LinksEnroll.JSON_PROPERTY_ENROLL })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-07-28T10:14:57.946459+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class LinksEnroll implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_ENROLL = "enroll";
    private LinksEnrollEnroll enroll;

    public LinksEnroll() {
    }

    public LinksEnroll enroll(LinksEnrollEnroll enroll) {

        this.enroll = enroll;
        return this;
    }

    /**
     * Get enroll
     *
     * @return enroll
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_ENROLL)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public LinksEnrollEnroll getEnroll() {
        return enroll;
    }

    @JsonProperty(JSON_PROPERTY_ENROLL)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setEnroll(LinksEnrollEnroll enroll) {
        this.enroll = enroll;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        LinksEnroll linksEnroll = (LinksEnroll) o;
        return Objects.equals(this.enroll, linksEnroll.enroll);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(enroll);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class LinksEnroll {\n");
        sb.append("    enroll: ").append(toIndentedString(enroll)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
